Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/_jb_pytest_runner.py | 53 | 51 | 0 | 20 | 1 | 4%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/_jb_runner_tools.py | 204 | 134 | 0 | 62 | 10 | 35%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/_jb_serial_tree_manager.py | 57 | 13 | 0 | 26 | 7 | 66%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/teamcity/__init__.py | 6 | 5 | 0 | 0 | 0 | 17%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/teamcity/common.py | 98 | 91 | 0 | 42 | 1 | 9%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/teamcity/jb_local_exc_store.py | 11 | 3 | 0 | 0 | 0 | 73%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/teamcity/messages.py | 154 | 115 | 0 | 28 | 7 | 27%
/Applications/PyCharm.app/Contents/plugins/python-ce/helpers/pycharm/teamcity/pytest_plugin.py | 293 | 193 | 0 | 120 | 30 | 35%
src/cgse_dummy/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/cgse_dummy/dummy_dev.py | 136 | 57 | 0 | 24 | 8 | 54%
src/cgse_dummy/dummy_sim.py | 153 | 103 | 0 | 30 | 1 | 28%
src/cgse_dummy/sim_data.py | 55 | 10 | 0 | 4 | 1 | 78%
tests/test_dummy_sim.py | 29 | 17 | 0 | 0 | 0 | 41%
/Users/rik/github/cgse/libs/cgse-common/src/cgse_common/__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
/Users/rik/github/cgse/libs/cgse-common/src/egse/decorators.py | 331 | 266 | 3 | 34 | 0 | 18%
/Users/rik/github/cgse/libs/cgse-common/src/egse/device.py | 113 | 37 | 2 | 4 | 0 | 65%
/Users/rik/github/cgse/libs/cgse-common/src/egse/env.py | 225 | 157 | 187 | 68 | 4 | 26%
/Users/rik/github/cgse/libs/cgse-common/src/egse/exceptions.py | 20 | 0 | 0 | 0 | 0 | 100%
/Users/rik/github/cgse/libs/cgse-common/src/egse/log.py | 71 | 21 | 0 | 16 | 4 | 67%
/Users/rik/github/cgse/libs/cgse-common/src/egse/plugin.py | 125 | 80 | 0 | 32 | 2 | 31%
/Users/rik/github/cgse/libs/cgse-common/src/egse/settings.py | 130 | 36 | 51 | 30 | 8 | 66%
/Users/rik/github/cgse/libs/cgse-common/src/egse/system.py | 774 | 561 | 6 | 214 | 11 | 23%
/Users/rik/github/cgse/libs/cgse-core/src/cgse_core/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
Total | 3042 | 1950 | 249 | 754 | 95 | 33%

No items found using the specified filter.